@@ -577,7 +577,7 @@ class EndpointPipelinePublisher:
             publisher = PipelinePublisher(self.ws)
             published_pipeline = publisher.publish(experiment_name, pipeline_name)
             
-            pipeline_endpoint.add(published_pipeline)
+            pipeline_endpoint.add_default(published_pipeline)
             published_endpoint = published_pipeline.endpoint
             
         return published_endpoint
@@ -1375,6 +1375,10 @@ class HumlLargeFileUploader:
         self.feature_index = feature_index
     
     def _upload_file(self, data, file_blob_dest, index, ext):
+
+        #make directory if does not exist    
+        os.makedirs(self.directory_path, exist_ok=True)
+
         filename = "block_{0}.{1}".format(index, ext)
         file = os.path.join(self.directory_path, filename)
         #if not os.path.isfile(file):
